==> vector_tile-0.1.5.tar.gz: lib/vector_tile_layer.dart <==
import 'package:meta/meta.dart';
import 'package:vector_tile/raw/raw_vector_tile.dart' as raw;
import 'package:vector_tile/vector_tile_geom_type.dart';
import 'package:vector_tile/vector_tile_feature.dart';
import 'package:vector_tile/vector_tile_value.dart';

class VectorTileLayer {
  String name;
  int extent;
  int version;
  List<String> keys;
  List<VectorTileValue> values;
  List<VectorTileFeature> features;

  VectorTileLayer({
    @required this.name,
    @required this.extent,
    @required this.version,
    this.keys,
    this.values,
    this.features,
  });

  static VectorTileLayer fromRaw({@required raw.VectorTile_Layer rawLayer}) {
    List<VectorTileValue> values = rawLayer.values.map((value) {
      return VectorTileValue(
        stringValue: value.stringValue,
        floatValue: value.floatValue,
        doubleValue: value.doubleValue,
        intValue: value.intValue,
        uintValue: value.uintValue,
        sintValue: value.sintValue,
        boolValue: value.boolValue,
      );
    }).toList();
    List<VectorTileFeature> features = rawLayer.features.map((feature) {
      return VectorTileFeature(
        id: feature.id,
        tags: feature.tags,
        type: VectorTileGeomTypeExtension.fromRaw(feature.type),
        geometryList: feature.geometry,
        extent: rawLayer.extent,
        keys: rawLayer.keys,
        values: values,
      );
    }).toList();
    
    return VectorTileLayer(
      name: rawLayer.name,
      extent: rawLayer.extent,
      version: rawLayer.version,
      keys: rawLayer.keys,
      values: values,
      features: features,
    );
  }
}

==> vector_tile-0.1.6.tar.gz: lib/vector_tile_layer.dart <==
import 'package:meta/meta.dart';
import 'package:vector_tile/raw/raw_vector_tile.dart' as raw;
import 'package:vector_tile/vector_tile_geom_type.dart';
import 'package:vector_tile/vector_tile_feature.dart';
import 'package:vector_tile/vector_tile_value.dart';

class VectorTileLayer {
  String name;
  int extent;
  int version;
  List<String> keys;
  List<VectorTileValue> values;
  List<VectorTileFeature> features;

  VectorTileLayer({
    @required this.name,
    @required this.extent,
    @required this.version,
    this.keys,
    this.values,
    this.features,
  });

  static VectorTileLayer fromRaw({@required raw.VectorTile_Layer rawLayer}) {
    List<VectorTileValue> values = rawLayer.values.map((value) {
      return VectorTileValue(
        stringValue: value.hasStringValue() ? value.stringValue : null,
        floatValue: value.hasFloatValue() ? value.floatValue : null,
        doubleValue: value.hasDoubleValue() ? value.doubleValue : null,
        intValue: value.hasIntValue() ? value.intValue : null,
        uintValue: value.hasUintValue() ? value.uintValue : null,
        sintValue: value.hasSintValue() ? value.sintValue : null,
        boolValue: value.hasBoolValue() ? value.boolValue : null,
      );
    }).toList();
    List<VectorTileFeature> features = rawLayer.features.map((feature) {
      return VectorTileFeature(
        id: feature.id,
        tags: feature.tags,
        type: VectorTileGeomTypeExtension.fromRaw(feature.type),
        geometryList: feature.geometry,
        extent: rawLayer.extent,
        keys: rawLayer.keys,
        values: values,
      );
    }).toList();
    
    return VectorTileLayer(
      name: rawLayer.name,
      extent: rawLayer.extent,
      version: rawLayer.version,
      keys: rawLayer.keys,
      values: values,
      features: features,
    );
  }
}
